/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.userupdate.hook;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import se.vgregion.userupdate.domain.PropertiesBean;

import com.liferay.portal.kernel.events.Action;
import com.liferay.portal.kernel.events.ActionException;

/**
 * Created by IntelliJ IDEA. Created: 2011-11-22 23:37
 * 
 * @author <a href="mailto:david.rosell@redpill-linpro.com">David Rosell</a>
 */
public class ExternalUserLogoutAction extends Action {
    private static final Logger LOGGER = LoggerFactory.getLogger(ExternalUserLogoutAction.class);
    private ApplicationContext applicationContext;

    @Override
    public void run(HttpServletRequest request, HttpServletResponse response) throws ActionException {

        if (externalAccessRule(request)) {
            LOGGER.info("Is external user, will send redirect");
            try {
                PropertiesBean propertiesBean = (PropertiesBean) getApplicationContext().getBean("propertiesBean");
                response.sendRedirect(propertiesBean.getExternalUserRedirectUrl());
            } catch (IOException e) {
                log(e.getMessage(), e);
            }
        }

    }

    private boolean externalAccessRule(HttpServletRequest request) {
        String header = request.getHeader("x-forwarded-for");
        PropertiesBean propertiesBean = (PropertiesBean) getApplicationContext().getBean("propertiesBean");
        if (header != null) {
            // Iterate over the ip:s. We'll find a match if the user is located externally.
            for (String ip : propertiesBean.getIpsForExternalAccess()) {
                if (header.contains(ip)) { // String.contains(...) since the header value may be a comma-separated list.
                    return true;
                }
            }
        }
        return false;
    }

    private ApplicationContext getApplicationContext() {
        if (applicationContext == null) {
            applicationContext = new ClassPathXmlApplicationContext("applicationContext.xml");
        }
        return applicationContext;
    }

    private void log(String msg, Throwable ex) {
        if (LOGGER.isDebugEnabled()) {
            LOGGER.warn(msg, ex);
        } else {
            LOGGER.warn(msg);
        }
    }
}
